@@ -1,23 +1,24 @@
-/*-------------------------------------------------------------------------------|
-|                                                                                |
-|        Copyright (C) 1999  Emergent IT Inc.  and Raytheon Systems Company      |
-|                                                                                |
-|  Permission to use, modify, and distribute this software and its documentation |
-|  for any purpose without fee is hereby granted, provided that the above        |
-|  copyright notice appear in all copies and that both that copyright notice and | 
-|  this permission notice appear in supporting documentation.                    |
-|                                                                                |
-|--------------------------------------------------------------------------------|
-|                                                                                |
-| This is the main header file to be distributed with the HDF-EOS library.       |
-|                                                                                |
-| Last date updated: June 5, 2001                                                |
-|                    Aug 23, 2001  A.M. Added thread-safe related blocks.        |
-|                    May 29, 2002  S.Z  Added ZA interface                       |
-|                    August, 2003  S.Z  Added szip compression methods.          |
-|                    April,  2004  S.Z  Added a data type flag HE5T_CHARSTRING   |
-|                    August, 2004  S.Z  Added field number type in HE5_CmpDTSinfo|
---------------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------------|
+|                                                                             |
+|        Copyright (C) 1999  Emergent IT Inc.  and Raytheon Systems Company   |
+|                                                                             |
+|Permission to use, modify, and distribute this software and its documentation|
+|for any purpose without fee is hereby granted, provided that the above       |
+|copyright notice appear in all copies and that both that copyright notice and|
+|this permission notice appear in supporting documentation.                   |
+|                                                                             |
+|-----------------------------------------------------------------------------|
+|                                                                             |
+| This is the main header file to be distributed with the HDF-EOS library.    |
+|                                                                             |
+| Last date updated: June 5, 2001                                             |
+|                    Aug 23, 2001  A.M. Added thread-safe related blocks.     |
+|                    May 29, 2002  S.Z  Added ZA interface                    |
+|                    August, 2003  S.Z  Added szip compression methods.       |
+|                    April,  2004  S.Z  Added a data type flag HE5T_CHARSTRING|
+|                    August, 2004  S.Z  Added field number type in            |
+|                                       HE5_CmpDTSinfo                        |
+-----------------------------------------------------------------------------*/
 
 
 #ifndef HE5_HDFEOSDEF_H_
@@ -25,6 +26,10 @@
 
 #include <hdf5.h>
 
+#ifdef H5_USE_16_API
+#include <H5DSpublic.h>
+#endif
+
 #include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -39,7 +44,7 @@
 #endif
 
 
-#define HE5_HDFEOSVERSION "1.12"
+#define HE5_HDFEOSVERSION "1.13"
 
 #define H5_USE_16_API 1
 
@@ -129,17 +134,17 @@ typedef struct
 
 typedef struct
 {
-  int                     nfields;                 /* Number of data fields    */
-  int                     rank[HE5_FLDNUMBERMAX];  /* Fields rank array        */
-  int                     array[HE5_FLDNUMBERMAX]; /* Flag if field is an array*/
-  char                    *fieldname[HE5_FLDNUMBERMAX];/* Array of field names */
-                                                   /* Array of dimension sizes */ 
-  size_t                  dims[HE5_FLDNUMBERMAX][HE5_DTSETRANKMAX];
-  size_t                  datasize;                /* Size of data (bytes)     */
-  size_t                  offset[HE5_FLDNUMBERMAX];/* Array of field offsets   */
-  hid_t                   dtype[HE5_FLDNUMBERMAX]; /* Array of field type IDs  */
-  hid_t                   numtype[HE5_FLDNUMBERMAX];/* Array of field number type IDs */
-  H5T_class_t             dclass[HE5_FLDNUMBERMAX];/* Array of field class IDs */
+  int            nfields;                  /* Number of data fields    */
+  int            rank[HE5_FLDNUMBERMAX];   /* Fields rank array        */
+  int            array[HE5_FLDNUMBERMAX];  /* Flag if field is an array*/
+  char           *fieldname[HE5_FLDNUMBERMAX];/* Array of field names     */
+                                              /* Array of dimension sizes */ 
+  size_t         dims[HE5_FLDNUMBERMAX][HE5_DTSETRANKMAX];
+  size_t         datasize;                 /* Size of data (bytes)     */
+  size_t         offset[HE5_FLDNUMBERMAX]; /* Array of field offsets   */
+  hid_t          dtype[HE5_FLDNUMBERMAX];  /* Array of field type IDs  */
+  hid_t          numtype[HE5_FLDNUMBERMAX];/* Array of field number type IDs */
+  H5T_class_t    dclass[HE5_FLDNUMBERMAX]; /* Array of field class IDs */
 }HE5_CmpDTSinfo;
 
 typedef  struct 
@@ -399,22 +404,22 @@ HE5_HDFE_MutexStruct   GlobalMutex;
 
 /* Macro for first thread initialization */
 /* ------------------------------------- */
-#define HE5_FIRST_THREAD_INIT  {                                               \
-   status = pthread_once(&HE5_HDFE_TS_FirstInit, HE5_TSinitfirst);             \
+#define HE5_FIRST_THREAD_INIT  {                                             \
+   status = pthread_once(&HE5_HDFE_TS_FirstInit, HE5_TSinitfirst);           \
 }
 
 /* Macro for locking the mutex */
 /* --------------------------- */
-#define HE5_LOCK        {                                                       \
-   status = HE5_TSmutexlock(&GlobalMutex);                                      \
-     if (status != SUCCEED) goto COMPLETION;                                    \
+#define HE5_LOCK        {                                                    \
+   status = HE5_TSmutexlock(&GlobalMutex);                                   \
+     if (status != SUCCEED) goto COMPLETION;                                 \
 }
 
 /* Macro for unlocking the mutex */
 /* ----------------------------- */
-#define HE5_UNLOCK      {                                                       \
-   status = HE5_TSmutexunlock(&GlobalMutex);                                    \
-     if (status != SUCCEED) goto COMPLETION;                                    \
+#define HE5_UNLOCK      {                                                    \
+   status = HE5_TSmutexunlock(&GlobalMutex);                                 \
+     if (status != SUCCEED) goto COMPLETION;                                 \
 }
 
 #else  /* -D_HDFEOS5_THREADSAFE */
@@ -577,7 +582,7 @@ herr_t  HE5_SWsetfillvalue(hid_t swathID, char *fieldname, hid_t ntype, void *fi
 herr_t  HE5_SWsetalias(hid_t swathID, char *fieldname, const char *aliaslist);
 herr_t  HE5_SWdropalias(hid_t swathID, int fldgroup, const char *aliasname);
 herr_t  HE5_SWfldrename(hid_t swathID, char *oldfieldname, const char *newfieldname);
-
+herr_t  HE5_SWsetdimscale(hid_t swathID, char *fieldname, char *dimname,const hsize_t dimsize, hid_t numbertype, void * data);
 
 /* I/O routines */
 
@@ -593,7 +598,7 @@ herr_t  HE5_SWreadlocattr(hid_t swathID, const char *fieldname, const char *attr
 herr_t  HE5_SWwritefield(hid_t swathID, char *fieldname, const hssize_t start[], const hsize_t stride[], const hsize_t edge[],  void *data);
 herr_t  HE5_SWreadfield(hid_t swathID, char *fieldname, const hssize_t start[], const hsize_t stride[], const hsize_t edge[],  void *data);
 herr_t  HE5_SWwritegeometa(hid_t swathID, const char *fieldname, char *dimlist, hid_t mvalue);
-
+herr_t  HE5_SWwritedscaleattr(hid_t swathID, const char *fieldname, const char *attrname, hid_t numtype, hsize_t  count[],  void *datbuf);
 
 /* Inquiry routines */
 
@@ -628,7 +633,10 @@ herr_t  HE5_SWaliasinfo(hid_t swathID, int fldgroup, const char *aliasname, int
 long    HE5_SWinqdfldalias(hid_t swathID, char *fldalias, long *strbufsize);
 long    HE5_SWinqgfldalias(hid_t swathID, char *fldalias, long *strbufsize);
 long    HE5_SWgetaliaslist(hid_t swathID, int fldgroup, char *aliaslist, long *strbufsize);
-
+long    HE5_SWgetdimscale(hid_t swathID, char *fieldname, char *dimname, hsize_t *dimsize, hid_t *numbertype, void * databuff);
+herr_t  HE5_SWdscaleattrinfo(hid_t swathID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count);
+herr_t  HE5_SWreaddscaleattr(hid_t swathID, const char *fieldname, const char *attrname, void *datbuf);
+long    HE5_SWinqdscaleattrs(hid_t swathID, const char *fieldname, char *attrnames, long *strbufsize);
 
 /* Subsetting/Retrieving routines */
 
@@ -711,6 +719,7 @@ herr_t   HE5_GDdeffield(hid_t gridID, const char *fieldname, char *dimlist, char
 herr_t   HE5_GDsetfillvalue(hid_t gridID, const char *fieldname, hid_t ntype, void *fillval);
 herr_t   HE5_GDsetalias(hid_t gridID, char *fieldname, const char *aliaslist);
 herr_t   HE5_GDdropalias(hid_t gridID, int fldgroup, const char *aliasname);
+herr_t   HE5_GDsetdimscale(hid_t gridID, char *fieldname, char *dimname,const hsize_t dimsize, hid_t numbertype, void * data);
 
 
 /* I/O routines */
@@ -753,7 +762,11 @@ herr_t   HE5_GDtileinfo(hid_t gridID, char *fieldname, int *tilecode, int *tiler
 herr_t   HE5_GDaliasinfo(hid_t gridID, int fldgroup, const char *aliasname, int *length, char *buffer);
 long     HE5_GDinqfldalias(hid_t gridID, char *fldalias, long *strbufsize);
 long     HE5_GDgetaliaslist(hid_t gridID, int fldgroup, char *aliaslist, long *strbufsize);
-
+long     HE5_GDgetdimscale(hid_t gridID, char *fieldname, char *dimname, hsize_t *dimsize, hid_t *numbertype, void * databuff);
+herr_t   HE5_GDwritedscaleattr(hid_t gridID, const char *fieldname, const char *attrname, hid_t numtype, hsize_t  count[],  void *datbuf);
+herr_t   HE5_GDdscaleattrinfo(hid_t gridID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count);
+herr_t   HE5_GDreaddscaleattr(hid_t gridID, const char *fieldname, const char *attrname, void *datbuf);
+long     HE5_GDinqdscaleattrs(hid_t gridID, const char *fieldname, char *attrnames, long *strbufsize);
 
 /* Subsetting/Retrieving routines */
 
@@ -867,8 +880,9 @@ herr_t  HE5_ZAsetfillvalue(hid_t zaID, char *fieldname, hid_t ntype, void *fillv
 herr_t  HE5_ZAsetalias(hid_t zaID, char *fieldname, const char *aliaslist);
 herr_t  HE5_ZAdropalias(hid_t zaID, int fldgroup, const char *aliasname);
 herr_t  HE5_ZAfldrename(hid_t zaID, char *oldfieldname, const char *newfieldname);
- 
- 
+herr_t  HE5_ZAsetdimscale(hid_t zaID, char *fieldname, char *dimname, const hsize_t dimsize, hid_t numbertype, void * data);
+long    HE5_ZAgetdimscale(hid_t zaID, char *fieldname, char *dimname, hsize_t *dimsize, hid_t *numbertype, void * databuff);
+
 /* I/O routines */
  
 herr_t  HE5_ZAwritedatameta(hid_t zaID, const char *fieldname, char *dimlist, hid_t mvalue);
@@ -880,7 +894,8 @@ herr_t  HE5_ZAreadgrpattr(hid_t zaID, const char *attrname, void *datbuf);
 herr_t  HE5_ZAreadlocattr(hid_t zaID, const char *fieldname, const char *attrname, void *datbuf);
 herr_t  HE5_ZAwrite(hid_t zaID, char *za_name, const hssize_t start[], const hsize_t stride[], const hsize_t count[],  void *datbuf);
 herr_t  HE5_ZAread(hid_t zaID, char *za_name, const hssize_t start[], const hsize_t stride[], const hsize_t count[],  void *datbuf);
- 
+herr_t HE5_ZAreaddscaleattr(hid_t zaID, const char *fieldname, const char *attrname, void *datbuf);
+herr_t HE5_ZAwritedscaleattr(hid_t zaID, const char *fieldname, const char *attrname, hid_t numtype, hsize_t  count[],  void *datbuf); 
  
 /* Inquiry routines */
  
@@ -904,8 +919,9 @@ herr_t  HE5_ZAaliasinfo(hid_t zaID, int fldgroup, const char *aliasname, int *le
 long    HE5_ZAinqfldalias(hid_t zaID, char *fldalias, long *strbufsize);
 herr_t  HE5_ZAchunkinfo(hid_t zaID, char *fieldname, int *ndims, hsize_t dims[]);
 long    HE5_ZAgetaliaslist(hid_t zaID, int fldgroup, char *aliaslist, long *strbufsize);
- 
- 
+herr_t HE5_ZAdscaleattrinfo(hid_t zaID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count);
+long HE5_ZAinqdscaleattrs(hid_t zaID, const char *fieldname, char *attrnames, long *strbufsize);
+
 /*
  *******************************
  *   EXTERNAL DATA FILES       *
